package xyz.ibatv.nethercraft.block;

import net.minecraft.block.*;
import net.minecraft.block.piston.PistonBehavior;
import net.minecraft.entity.effect.StatusEffects;
import net.minecraft.item.BlockItem;
import net.minecraft.item.Item;
import net.minecraft.registry.Registries;
import net.minecraft.registry.Registry;
import net.minecraft.sound.BlockSoundGroup;
import net.minecraft.util.ColorCode;
import net.minecraft.util.Identifier;
import net.minecraft.util.math.intprovider.UniformIntProvider;
import xyz.ibatv.nethercraft.NethercraftClassic;
import xyz.ibatv.nethercraft.block.custom.DarkWheatCropBlock;
import xyz.ibatv.nethercraft.block.custom.LavaReedsBlock;
import xyz.ibatv.nethercraft.block.custom.ModFarmBlock;
import xyz.ibatv.nethercraft.block.custom.ModSaplingBlock;
import xyz.ibatv.nethercraft.world.tree.ModSaplingGenerators;

public class ModBlocks {

    public static final Block GLOWOOD_LOG = registerBlock("glowood_log",
            new PillarBlock(AbstractBlock.Settings.copy(Blocks.OAK_LOG)));

    public static final Block GLOWOOD_PLANKS = registerBlock("glowood_planks",
            new Block(AbstractBlock.Settings.copy(Blocks.OAK_PLANKS)));
    public static final Block GLOWOOD_LEAVES = registerBlock("glowood_leaves",
            new LeavesBlock(AbstractBlock.Settings.copy(Blocks.OAK_LEAVES)));

    public static final Block GLOWOOD_SAPLING = registerBlock("glowood_sapling",
            new ModSaplingBlock(ModSaplingGenerators.GLOWOOD, AbstractBlock.Settings.copy(Blocks.OAK_SAPLING), Blocks.NETHERRACK));

    public static final Block GLOWOOD_BOOKSHELF = registerBlock("glowood_bookshelf",
            new PillarBlock(AbstractBlock.Settings.copy(Blocks.BOOKSHELF)));

    public static final Block GLOWOOD_STAIRS = registerBlock("glowood_stairs",
            new StairsBlock(ModBlocks.GLOWOOD_PLANKS.getDefaultState(),
                    AbstractBlock.Settings.create().strength(2f).requiresTool()));

    public static final Block GLOWOOD_PRESSUREPLATE = registerBlock("glowood_pressureplate",
            new PressurePlateBlock(BlockSetType.OAK,
                    AbstractBlock.Settings.create().strength(2f).requiresTool()));

    public static final Block GLOWOOD_FENCE = registerBlock("glowood_fence",
            new FenceBlock(AbstractBlock.Settings.create().strength(2f).requiresTool()));

    public static final Block GLOWOOD_DOOR = registerBlock("glowood_door",
            new DoorBlock(BlockSetType.OAK,
                    AbstractBlock.Settings.create().strength(2f).requiresTool().nonOpaque()));

    public static final Block GLOWOOD_LADDER = registerBlock("glowood_ladder",
            new LadderBlock(AbstractBlock.Settings.copy(Blocks.LADDER).sounds(BlockSoundGroup.LADDER)));


    //nether_dirt
    public static final Block NETHER_DIRT = registerBlock("nether_dirt",
            new Block(AbstractBlock.Settings.create().strength(4f).sounds(BlockSoundGroup.GRAVEL)));

    public static final Block NETHER_DIRT_FARMLAND = registerBlock("nether_dirt_farmland",
            new ModFarmBlock(AbstractBlock.Settings.copy(Blocks.FARMLAND)));

    public static final Block SMOOTH_NETHERRACK = registerBlock("smooth_netherrack",
            new Block(AbstractBlock.Settings.copy(Blocks.NETHERRACK)));

    public static final Block FOULITE_ORE = registerBlock("foulite_ore",
            new ExperienceDroppingBlock(UniformIntProvider.create(1, 5),
                    AbstractBlock.Settings.create().strength(3f).requiresTool()));

    public static final Block W_ORE = registerBlock("w_ore",
            new ExperienceDroppingBlock(UniformIntProvider.create(1, 5),
                    AbstractBlock.Settings.create().strength(3f).requiresTool()));

    public static final Block LINIUM_ORE = registerBlock("linium_ore",
            new ExperienceDroppingBlock(UniformIntProvider.create(1, 5),
                    AbstractBlock.Settings.create().strength(3f).requiresTool()));

    public static final Block NERIDIUM_ORE = registerBlock("neridium_ore",
            new ExperienceDroppingBlock(UniformIntProvider.create(1, 5),
                    AbstractBlock.Settings.create().strength(3f).requiresTool()));

    public static final Block PYRIDIUM_ORE = registerBlock("pyridium_ore",
            new ExperienceDroppingBlock(UniformIntProvider.create(1, 5),
                    AbstractBlock.Settings.create().strength(3f).requiresTool()));


    public static final Block LINIUM_BLOCK = registerBlock("linium_block",
            new Block(AbstractBlock.Settings.copy(Blocks.IRON_BLOCK)));

    public static final Block NERIDIUM_BLOCK = registerBlock("neridium_block",
            new Block(AbstractBlock.Settings.copy(Blocks.IRON_BLOCK)));

    public static final Block PYRIDIUM_BLOCK = registerBlock("pyridium_block",
            new Block(AbstractBlock.Settings.copy(Blocks.IRON_BLOCK)));


    public static final Block NETHER_GLASS = registerBlock("nether_glass",
            new Block(AbstractBlock.Settings.copy(Blocks.GLASS).nonOpaque()));

    public static final Block SLOW_GLASS = registerBlock("slow_glass",
            new Block(AbstractBlock.Settings.copy(Blocks.GLASS).nonOpaque()));


    public static final Block HEAT_SAND = registerBlock("heat_sand",
            new ColoredFallingBlock(new ColorCode(12545589), AbstractBlock.Settings.copy(Blocks.SAND)));

    public static final Block GREEN_GLOWSHROOM = registerBlock("green_glowshroom",
            new FlowerBlock(StatusEffects.GLOWING, 10,
                    AbstractBlock.Settings.copy(Blocks.POPPY).nonOpaque().noCollision().breakInstantly().pistonBehavior(PistonBehavior.DESTROY)));

    public static final Block PURPLE_GLOWSHROOM = registerBlock("purple_glowshroom",
            new FlowerBlock(StatusEffects.GLOWING, 10,
                    AbstractBlock.Settings.copy(Blocks.POPPY).nonOpaque().noCollision().breakInstantly().pistonBehavior(PistonBehavior.DESTROY)));

    //public static final Block LAVA_REEDS = registerBlock("lava_reeds",
    //        new SugarCaneBlock(AbstractBlock.Settings.copy(Blocks.SUGAR_CANE).noCollision().nonOpaque()
    //                .ticksRandomly().breakInstantly().pistonBehavior(PistonBehavior.DESTROY)));



    public static final Block LAVA_REEDS = registerBlock("lava_reeds",
            new LavaReedsBlock(AbstractBlock.Settings.copy(Blocks.SUGAR_CANE).noCollision().nonOpaque()
                    .ticksRandomly().breakInstantly().pistonBehavior(PistonBehavior.DESTROY)));



    public static final Block DARK_WHEAT_CROP = registerBlockWithoutBlockItem("dark_wheat_crop",
            new DarkWheatCropBlock(AbstractBlock.Settings.create().noCollision()
                    .ticksRandomly().breakInstantly().sounds(BlockSoundGroup.CROP).pistonBehavior(PistonBehavior.DESTROY)));




    private static Block registerBlockWithoutBlockItem(String name, Block block){
        return Registry.register(Registries.BLOCK, Identifier.of(NethercraftClassic.MOD_ID, name), block);
    }

    private static Block registerBlock(String name, Block block){
        registerBlockItem(name, block);
        return Registry.register(Registries.BLOCK, Identifier.of(NethercraftClassic.MOD_ID, name), block);
    }

    private static void registerBlockItem(String name, Block block){
        Registry.register(Registries.ITEM, Identifier.of(NethercraftClassic.MOD_ID, name),
                new BlockItem(block, new Item.Settings()));
    }

    public static void registerModBlocks(){
        NethercraftClassic.LOGGER.info("Registering Mod blocks for " + NethercraftClassic.MOD_ID);

    }
}
